@@ -1,16 +1,37 @@
 # Author: Robert J. Hijmans
 # Date : June 2008
-# Version 0.9
+# Version 1.0
 # Licence GPL v3
 
 
-.rasterFromRasterFile <- function(filename, band=1, type='RasterLayer') {
-	valuesfile <- raster:::.setFileExtensionValues(filename, "raster")
+.getRat <- function(x, ratvalues, ratnames, rattypes) {
+
+	rat <- data.frame(matrix(ratvalues, nrow=length(ratvalues) / length(ratnames)), stringsAsFactors=FALSE)
+	colnames(rat) <- ratnames
+	for (i in 1:ncol(rat)) {
+		if (rattypes[i] == 'integer') {
+			rat[, i] <- as.integer(rat[,i])
+		} else if (rattypes[i] == 'numeric') {
+			rat[, i] <- as.numeric(rat[,i])
+		} else if (rattypes[i] == 'factor') {
+			rat[, i] <- as.factor(rat[,i])
+		}
+	}
+	x@data@isfactor <- TRUE
+	x@data@attributes <- list(rat)
+	x
+	
+}
+
+
+.rasterFromRasterFile <- function(filename, band=1, type='RasterLayer', driver='raster', RAT=TRUE) {
+
+	valuesfile <- .setFileExtensionValues(filename, driver)
 	if (!file.exists( valuesfile )){
 		stop( paste(valuesfile,  "does not exist"))
 	}	
 	
-	filename <- raster:::.setFileExtensionHeader(filename, "raster")
+	filename <- .setFileExtensionHeader(filename, driver)
 	
 	ini <- readIniFile(filename)
 	ini[,2] = toupper(ini[,2]) 
@@ -25,11 +46,16 @@
 	nodataval <- -Inf
 	layernames <- ''
 	zvalues <- ''
+	zclass <- NULL
 	
 	isCat <- FALSE
 	ratnames <- rattypes <- ratvalues <- NULL
 	catlevels = matrix(NA)
-
+	w <- getOption('warn')
+	on.exit(options('warn' = w))
+	
+	#match(c("MINX", "MAXX", "MINY", "MAXY", "XMIN", "XMAX", "YMIN", "YMAX", "ROWS", "COLUMNS", "NROWS", "NCOLS"), toupper(ini[,2]))
+	
 	for (i in 1:length(ini[,1])) {
 		if (ini[i,2] == "MINX") { xn <- as.numeric(ini[i,3]) } 
 		else if (ini[i,2] == "MAXX") { xx <- as.numeric(ini[i,3]) } 
@@ -44,10 +70,18 @@
 		else if (ini[i,2] == "NROWS") { nr <- as.integer(ini[i,3]) } 
 		else if (ini[i,2] == "NCOLS") { nc <- as.integer(ini[i,3]) } 
 		
-		else if (ini[i,2] == "MINVALUE") { try ( minval <-  as.numeric(unlist(strsplit(ini[i,3], ':'))), silent = TRUE ) }
-		else if (ini[i,2] == "MAXVALUE") { try ( maxval <-  as.numeric(unlist(strsplit(ini[i,3], ':'))), silent = TRUE ) }
+	
+		else if (ini[i,2] == "MINVALUE") { 
+			options('warn'=-1) 
+			try ( minval <-  as.numeric(unlist(strsplit(ini[i,3], ':'))), silent = TRUE ) 
+			options('warn' = w)
+		}
+		else if (ini[i,2] == "MAXVALUE") { 
+			options('warn'=-1) 
+			try ( maxval <-  as.numeric(unlist(strsplit(ini[i,3], ':'))), silent = TRUE ) 
+			options('warn' = w)
+		}
 		else if (ini[i,2] == "VALUEUNIT") { try ( maxval <-  as.numeric(unlist(strsplit(ini[i,3], ':'))), silent = TRUE ) }
-
 		else if (ini[i,2] == "CATEGORICAL") { try ( isCat <-  as.logical(unlist(strsplit(ini[i,3], ':'))), silent = TRUE ) }
 				
 		#else if (ini[i,2] == "RATROWS") { ratrows <- as.integer(ini[i,3]) }
@@ -65,6 +99,7 @@
 		else if (ini[i,2] == "PROJECTION") { projstring <- ini[i,3] } 
 		else if (ini[i,2] == "LAYERNAME") { layernames <- ini[i,3] } 
 		else if (ini[i,2] == "ZVALUES") { zvalues <- ini[i,3] } 
+		else if (ini[i,2] == "ZCLASS") { zclass <- ini[i,3] } 
     }  
 	
 	if (projstring == 'GEOGRAPHIC') { projstring <- "+proj=longlat" }
@@ -94,27 +129,12 @@
 		x@data@band <- as.integer(band)
 		x@data@min <- minval[band]
 		x@data@max <- maxval[band]
-	}
-	
-	if (isTRUE(any(isCat))) {
-		x@data@isfactor <- isCat
-	
-	# currently only for a single layer!
-	
-		rat <- data.frame(matrix(ratvalues, nrow=length(ratvalues) / length(ratnames)), stringsAsFactors=FALSE)
-		colnames(rat) <- ratnames
-		for (i in 1:ncol(rat)) {
-			if (rattypes[i] == 'integer') {
-				rat[, i] <- as.integer(rat[,i])
-			} else if (rattypes[i] == 'numeric') {
-				rat[, i] <- as.numeric(rat[,i])
-			} else if (rattypes[i] == 'factor') {
-				rat[, i] <- as.factor(rat[,i])
+		if (RAT) {
+			if (isTRUE(isCat[band])) {
+		# currently only for a single layer!
+				try( x <- .getRat(ratvalues, ratnames, rattypes) )
 			}
 		}
-		x@data@isfactor <- TRUE
-		x@data@attributes <- list(rat)
-		
 	}
 
 	x@file@nbands <- as.integer(nbands)
@@ -140,6 +160,14 @@
 		zvalues <- unlist(strsplit(zvalues, ':'))
 		zname <- zvalues[1]
 		zvalues <- zvalues[-1]
+
+		if (!is.null(zclass)) {
+			if (zclass == 'Date') {
+				try( zvalues <- as.Date(zvalues), silent=TRUE )
+			} else {
+				try( zvalues <- as(zvalues, zclass), silent=TRUE )
+			}
+		}
 		if (type == 'RasterBrick') {
 			zvalues <- list(zvalues)
 		} else {
@@ -157,7 +185,6 @@
 	
 	dataType(x) <- inidatatype
 
-	x@file@name <- filename
 	x@data@haveminmax <- TRUE  # should check?
 	x@file@nodatavalue <- nodataval
 
@@ -165,13 +192,24 @@
 		x@file@byteorder <- byteorder 
 	} 	
 	x@data@fromdisk <- TRUE
-	
-	x@file@driver <- "raster"
+	x@file@driver <- driver
 
 #	if( dataSize(x) * (ncell(x) * nbands(x) + x@file@offset) !=  file.info(valuesfile)$size ) {
-	if( (dataSize(x) * ncell(x) * nbands(x))  !=  file.info(valuesfile)$size ) {
-		warning('size of values file does not match the number of cells (given the data type)')
+	
+	if (driver == 'big.matrix') {
+		require(bigmemory)
+		x@file@name <- valuesfile
+		dscfile <- extension(valuesfile, 'big.dsc')
+		attr(x@file, 'big.matrix') <- attach.big.matrix(dscfile)
+		
+	} else {
+		x@file@name <- filename
+		if( (dataSize(x) * ncell(x) * nbands(x))  !=  file.info(valuesfile)$size ) {
+			warning('size of values file does not match the number of cells (given the data type)')
+		}
 	}
 	
     return(x)
 }
+
+
