@@ -1,4 +1,4 @@
-# Author: Robert J. Hijmans, r.hijmans@gmail.com
+# Author: Robert J. Hijmans
 # Date : September 2009
 # Version 0.9
 # Licence GPL v3
@@ -22,10 +22,11 @@ setMethod('rotate', signature(x='Raster'),
 		r2 <- crop(x, extent(hx, e@xmax, e@ymin, e@ymax))
 		r2@extent@xmin <- r2@extent@xmin - xrange
 		r2@extent@xmax <- r2@extent@xmax - xrange
-		ln <- layerNames(x)
-		x <- merge(r1, r2, overlap=FALSE, ...)
-		layerNames(x) <- ln
-		return(x)
+		ln <- names(x)
+		out <- merge(r1, r2, overlap=FALSE, ...)
+		names(out) <- names(x)
+		out@z <- x@z
+		return(out)
 	}
 )
 
